==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_sq.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=sq
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'SHTO NJE DOKUMENT', # MODIF
	'bouton_ajouter_image' => 'SHTO NJE FIGURE', # MODIF

	// E
	'entree_dimensions' => 'Dimensioni:',
	'entree_titre_document' => 'Titulli i dokumentit:',
	'entree_titre_image' => 'Titulli i figurës:',

	// I
	'image_tourner_180' => 'Rrotullo me 180°',
	'image_tourner_droite' => 'Rrotullo me 90° djathtas',
	'image_tourner_gauche' => 'Rrotullo me 90° majtas',
	'info_document' => 'Dokument',
	'info_documents' => 'Dokumenta',
	'info_inclusion_directe' => 'Vendosje direkte:',
	'info_inclusion_vignette' => 'Vendosje e figurës:',
	'info_installer_tous_documents' => 'Instaloji te gjitha dokumentat',
	'info_logo_max_taille' => 'Përmasat maksimale për një logo janë @maxi@ (ky file është  @actuel@).',
	'info_portfolio' => 'Portfolio ',
	'info_telecharger' => 'Upload nga kompiuteri juaj:',
	'item_autoriser_selectionner_date_en_ligne' => 'Pouvoir sélectionner la date de mise en ligne de chaque document', # MODIF
	'item_non_autoriser_selectionner_date_en_ligne' => 'Ne pas pouvoir changer manuellement la date des documents', # MODIF

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'File ZIP',
	'upload_fichier_zip_texte' => 'File i propozuar është një file ZIP.',
	'upload_fichier_zip_texte2' => 'Ky file mund të jetë:',
	'upload_limit' => 'Ky file është shumë i madh për serverin, dimensioni maksimal për <i>ngarkimet</i> është @max@.',
	'upload_zip_decompacter' => ' i dekompresuar dhe çdo element i instaluar në faqe. File që do të instalohen në faqe janë:',
	'upload_zip_telquel' => ' instalohet kështu siç është sepse është Zip;'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_sq.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=sq
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'SHTO NJE DOKUMENT', # MODIF
	'bouton_ajouter_image' => 'SHTO NJE FIGURE', # MODIF

	// E
	'entree_dimensions' => 'Dimensioni:',
	'entree_titre_document' => 'Titulli i dokumentit:',
	'entree_titre_image' => 'Titulli i figurës:',

	// I
	'image_tourner_180' => 'Rrotullo me 180°',
	'image_tourner_droite' => 'Rrotullo me 90° djathtas',
	'image_tourner_gauche' => 'Rrotullo me 90° majtas',
	'info_document' => 'Dokument',
	'info_documents' => 'Dokumenta',
	'info_inclusion_directe' => 'Vendosje direkte:',
	'info_inclusion_vignette' => 'Vendosje e figurës:',
	'info_installer_tous_documents' => 'Instaloji te gjitha dokumentat',
	'info_logo_max_taille' => 'Përmasat maksimale për një logo janë @maxi@ (ky file është  @actuel@).',
	'info_portfolio' => 'Portfolio ',
	'info_telecharger' => 'Upload nga kompiuteri juaj:',
	'item_autoriser_selectionner_date_en_ligne' => 'Pouvoir sélectionner la date de mise en ligne de chaque document', # MODIF
	'item_non_autoriser_selectionner_date_en_ligne' => 'Ne pas pouvoir changer manuellement la date des documents', # MODIF

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'File ZIP',
	'upload_fichier_zip_texte' => 'File i propozuar është një file ZIP.',
	'upload_fichier_zip_texte2' => 'Ky file mund të jetë:',
	'upload_limit' => 'Ky file është shumë i madh për serverin, dimensioni maksimal për <i>ngarkimet</i> është @max@.',
	'upload_zip_decompacter' => ' i dekompresuar dhe çdo element i instaluar në faqe. File që do të instalohen në faqe janë:',
	'upload_zip_telquel' => ' instalohet kështu siç është sepse është Zip;',
];
